"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const options_keys_1 = require("../../model/options.keys");
const path = require("path");
const plumber = require("gulp-plumber");
const logger_1 = require("../services/logger");
const gulp = require('gulp');
const mergeJson = require('gulp-merge-json');
/**
 * Copy tsconfig-ngc.json to the outDir folder
 */
class CopyTsconfigNgcTask {
    /**
     * Registring the task
     */
    registerTask(argv, onError, dependencies = []) {
        const taskName = 'copy-tsconfig-ngc-task';
        logger_1.Logger.warning("\niniciando :" + taskName);
        const pathDefaultTsconfig = this.getPathToDefaultTsconfig();
        const pathCustomTsconfig = argv[options_keys_1.OptionsKeys.TSCONFIG] || pathDefaultTsconfig;
        gulp.task(taskName, dependencies, () => {
            return gulp.src([pathDefaultTsconfig, pathCustomTsconfig])
                .pipe(plumber(onError))
                .pipe(mergeJson({
                fileName: CopyTsconfigNgcTask.tsconfigName,
                concatArrays: false,
                mergeArrays: false
            }))
                .pipe(gulp.dest(argv[options_keys_1.OptionsKeys.OUT_DIR]));
        });
        return taskName;
    }
    /**
     * Get path to default tsconfig from current working directory (cwd)
     */
    getPathToDefaultTsconfig() {
        const pathFromDirname = path.resolve(__dirname, CopyTsconfigNgcTask.tsconfigPath);
        const relativePathFromCwd = path.relative(process.cwd(), pathFromDirname);
        return relativePathFromCwd;
    }
}
/**
 * tsconfig-ngc.json path.
 * Path from this file to tsconfig-ngc.json when project is compiled to javascript
 */
CopyTsconfigNgcTask.tsconfigName = 'tsconfig-ngc.json';
CopyTsconfigNgcTask.tsconfigPath = `../../${CopyTsconfigNgcTask.tsconfigName}`;
exports.CopyTsconfigNgcTask = CopyTsconfigNgcTask;
//# sourceMappingURL=copy-tsconfig-ngc.task.js.map